@@ -34,11 +34,12 @@ def importSLEAPbottomUP(inifile, dataFolder, currIDList):
     bpNamesCSVPath = os.path.join(projectPath, 'logs', 'measures', 'pose_configs', 'bp_names', 'project_bp_names.csv')
     poseEstimationSetting = config.get('create ensemble settings', 'pose_estimation_body_parts')
     print('Converting .slp into csv dataframes...')
+    csvPaths = []
 
     for filename in filesFound:
         print('Processing ' + str(os.path.basename(filename)) + '...')
         f = h5py.File(filename, 'r')
-        bpNames, orderVarList, OrderedBpList, MultiIndexCol, dfHeader, csvFilesFound, colorList, csvPaths, xy_heads, bp_cord_names, bpNameList, projBpNameList = [], [], [], [], [], [], [], [], [], [], [], []
+        bpNames, orderVarList, OrderedBpList, MultiIndexCol, dfHeader, csvFilesFound, colorList, xy_heads, bp_cord_names, bpNameList, projBpNameList = [], [], [], [], [], [], [], [], [], [], []
         final_dictionary = f.visititems(func)
         videoName = os.path.basename(final_dictionary['provenance']['video.path']).replace('.mp4', '')
         savePath = os.path.join(outputDfFolder, videoName + '.csv')
@@ -120,10 +121,10 @@ def importSLEAPbottomUP(inifile, dataFolder, currIDList):
             startCurrFrame = endCurrFrame
             frameCounter+=1
 
-    dataDf.fillna(0, inplace=True)
-    dataDf.to_csv(savePath, index=False)
-    csvPaths.append(savePath)
-    print('Saved file ' + savePath)
+        dataDf.fillna(0, inplace=True)
+        dataDf.to_csv(savePath, index=False)
+        csvPaths.append(savePath)
+        print('Saved file ' + savePath)
 
     ###### ASSIGN IDENTITIES
 
